﻿/* Fournit les options par défaut */
function defaultValues()
{
	dico =
	{
		version: browser.runtime.getManifest().version,
		scriptsURL: 'https://kigard.styragolin.net/KiCarte/',
		jqueryAtStart: false,
		system: '',
		toPublic: true,
		autoSend: false,
		debug: false,
		update: true
	}
	return dico
}

/* Relit les options actuelles et appelle une callback avec le résultat */
function readOptions(callback) {
	browser.storage.local.get(defaultValues()).then(
		callback,
		function(error) {
			console.log(error)
			callback(undefined)
		}
	)
}

/* Récupère les options spécifiques à l'utilisateur <userId> décrites dans le
   dictionnaire <userData> (fourni en entrée avec les valeurs par défaut) et
   appelle <callback> en retour avec le dictionnaire comportant les options.
   
   Le dictionnaire d'entrée <userData> comporte les clés réellement utilisées
   dans le stockage, et non la version simplifiée renvoyée.
   
   L'argument <options> est une liste d'options à récupérer. Les préférences
   utilisateur sont stockées avec un préfixe identifiant l'utilisateur, qui
   ne doit pas être repris dans le dictionnaire de retour.
*/
function readListedUserOptions(userId, userData, options, callback)
{
    var prefixe = 'options.' + userId + '.'
    browser.storage.local.get(userData).then(
		function(response) {
        	data = {}
        	for (var i in options) data[options[i]] = response[prefixe + options[i]]
        	callback(data)
		},
		function(error) {
            console.log(error)
            callback(undefined, error)
        }
	)
}

/* Récupère les options spécifiques à un utilisateur et appelle une callback
   en retour avec un dictionnaire comportant les options.
   L'argument "options" est un dictionnaire avec les valeurs par défaut.
   S'il est omis (undefined) ou nul, toutes les options de l'utilisateur sont
   récupérées et renvoyées. */
function readUserOptions(userId, options, callback)
{
    var prefixe = 'options.' + userId + '.'
    if (options !== undefined && options != null) {
        optionslist = []
        userdata = {}
        for (var k in options) {
            optionslist.push(k)
            userdata[prefixe + k] = options[k]
        }
        readListedUserOptions(userId, userdata, optionslist, callback)
    } else {
        useroptions = {}
        useroptions[prefixe + 'options'] = []
        browser.storage.local.get(useroptions).then(
			function(response) {
            	userdata = {}
            	var optionslist = ['akey'].concat(response[prefixe + 'options'])
            	for (var i in optionslist) userdata[prefixe + optionslist[i]] = null
            	readListedUserOptions(userId, userdata, optionslist, callback)
        	},
			function(error) {
                console.log(error)
                callback(undefined, error)
            }
		)
    }
}
